@@ -1,12 +1,12 @@
 from __future__ import absolute_import
 
+from six.moves import xrange
 from twisted.internet import reactor
 from twisted.internet.defer import Deferred, succeed
 from twisted.internet.task import Clock, deferLater, LoopingCall
 
 from .base import TestBase
 from ..taskmanager import CLEANUP_FREQUENCY, TaskManager
-from ..util import grange
 
 
 class TestTaskManager(TestBase):
@@ -22,7 +22,7 @@ class TestTaskManager(TestBase):
 
     def tearDown(self):
         self.tm.shutdown_task_manager()
-        super(TestTaskManager, self).tearDown()
+        return super(TestTaskManager, self).tearDown()
 
     def test_call_later(self):
         self.tm.register_task("test", reactor.callLater(10, lambda: None))
@@ -56,9 +56,6 @@ class TestTaskManager(TestBase):
     def test_delayed_looping_call_requires_interval(self):
         self.assertRaises(ValueError, self.tm.register_task, "test", LoopingCall(lambda: None), delay=1)
 
-    def test_delayed_deferred_requires_value(self):
-        self.assertRaises(ValueError, self.tm.register_task, "test", deferLater(reactor, 0.0, lambda: None), delay=1)
-
     def test_delayed_looping_call_requires_LoopingCall_or_Deferred(self):
         self.assertRaises(ValueError, self.tm.register_task, "test not Deferred nor LoopingCall",
                           self.tm._reactor.callLater(0, lambda: None), delay=1)
@@ -137,7 +134,7 @@ class TestTaskManager(TestBase):
         Test if the tasks are cleaned up after the cleanup frequency has been met.
         """
         deferred = succeed(None)
-        for _ in grange(CLEANUP_FREQUENCY):
+        for _ in xrange(CLEANUP_FREQUENCY):
             self.tm.register_anonymous_task("test", deferred)
 
         deferred_list = self.tm.wait_for_deferred_tasks()
@@ -149,7 +146,7 @@ class TestTaskManager(TestBase):
         """
         deferred = succeed(None)
         self.tm.register_anonymous_task("test", Deferred()).addErrback(lambda _: None)
-        for _ in grange(CLEANUP_FREQUENCY-1):
+        for _ in xrange(CLEANUP_FREQUENCY-1):
             self.tm.register_anonymous_task("test", deferred)
 
         deferred_list = self.tm.wait_for_deferred_tasks()
